sshsig
======

[Check Signature Tutorial](tutorial/check_signature.md)

[How to Check a Git Commit Signature](howto/check_commit.md)

[API reference](reference.md)


Install
-------

```
pip install sshlib
```
